@@ -30,13 +30,15 @@ import logging
 import sys
 from itertools import chain
 
+from ..connection_pool import ConnectionPool
 from ..exceptions import (
     ConnectionError,
     ConnectionTimeout,
     SerializationError,
     TransportError,
 )
-from ..transport import Transport
+from ..serializer import JSONSerializer
+from ..transport import Transport, get_host_info
 from .compat import get_running_loop
 from .http_aiohttp import AIOHttpConnection
 
@@ -53,7 +55,25 @@ class AsyncTransport(Transport):
 
     DEFAULT_CONNECTION_CLASS = AIOHttpConnection
 
-    def __init__(self, hosts, *args, sniff_on_start=False, **kwargs):
+    def __init__(
+        self,
+        hosts,
+        connection_class=None,
+        connection_pool_class=ConnectionPool,
+        host_info_callback=get_host_info,
+        sniff_on_start=False,
+        sniffer_timeout=None,
+        sniff_timeout=0.1,
+        sniff_on_connection_fail=False,
+        serializer=JSONSerializer(),
+        serializers=None,
+        default_mimetype="application/json",
+        max_retries=3,
+        retry_on_status=(502, 503, 504),
+        retry_on_timeout=False,
+        send_get_body_as="GET",
+        **kwargs
+    ):
         """
         :arg hosts: list of dictionaries, each containing keyword arguments to
             create a `connection_class` instance
@@ -97,7 +117,22 @@ class AsyncTransport(Transport):
         self._sniff_on_start_event = None  # type: asyncio.Event
 
         super(AsyncTransport, self).__init__(
-            *args, hosts=[], sniff_on_start=False, **kwargs
+            hosts=[],
+            connection_class=connection_class,
+            connection_pool_class=connection_pool_class,
+            host_info_callback=host_info_callback,
+            sniff_on_start=False,
+            sniffer_timeout=sniffer_timeout,
+            sniff_timeout=sniff_timeout,
+            sniff_on_connection_fail=sniff_on_connection_fail,
+            serializer=serializer,
+            serializers=serializers,
+            default_mimetype=default_mimetype,
+            max_retries=max_retries,
+            retry_on_status=retry_on_status,
+            retry_on_timeout=retry_on_timeout,
+            send_get_body_as=send_get_body_as,
+            **kwargs
         )
 
         # Since we defer connections / sniffing to not occur
