@@ -24,6 +24,7 @@
 #  specific language governing permissions and limitations
 #  under the License.
 
+
 import time
 from itertools import chain
 
@@ -46,14 +47,14 @@ def get_host_info(node_info, host):
 
     Useful for filtering nodes (by proximity for example) or if additional
     information needs to be provided for the :class:`~opensearchpy.Connection`
-    class. By default master only nodes are filtered out since they shouldn't
+    class. By default cluster_manager only nodes are filtered out since they shouldn't
     typically be used for API operations.
 
     :arg node_info: node information from `/_cluster/nodes`
     :arg host: connection information (host, port) extracted from the node info
     """
-    # ignore master only nodes
-    if node_info.get("roles", []) == ["master"]:
+    # ignore cluster_manager only nodes
+    if node_info.get("roles", []) == ["cluster_manager"]:
         return None
     return host
 
@@ -454,6 +455,8 @@ class Transport(object):
         timeout = None
         if params:
             timeout = params.pop("request_timeout", None)
+            if not timeout:
+                timeout = params.pop("timeout", None)
             ignore = params.pop("ignore", ())
             if isinstance(ignore, int):
                 ignore = (ignore,)
